summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/widgets/tqtabbar.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
commiteaa7ee2e0bbca40ba3173c4304f81957e8964291 (patch)
tree4f793aa48a5080aedc94ce6e519c3b86708f2b88 /tqtinterface/qt4/src/widgets/tqtabbar.cpp
parent79a9d7a46a20d4a0923bc06fc471fdc2176ef865 (diff)
downloadexperimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.tar.gz
experimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains
Diffstat (limited to 'tqtinterface/qt4/src/widgets/tqtabbar.cpp')
-rw-r--r--tqtinterface/qt4/src/widgets/tqtabbar.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/tqtinterface/qt4/src/widgets/tqtabbar.cpp b/tqtinterface/qt4/src/widgets/tqtabbar.cpp
index dd31f44..fd02625 100644
--- a/tqtinterface/qt4/src/widgets/tqtabbar.cpp
+++ b/tqtinterface/qt4/src/widgets/tqtabbar.cpp
@@ -261,7 +261,7 @@ public:
void add( TQTab * tab, const TQString & tip )
{
- tabTips.tqreplace( tab, tip );
+ tabTips.replace( tab, tip );
}
void remove( TQTab * tab )
@@ -272,7 +272,7 @@ public:
TQString tipForTab( TQTab * tab ) const
{
TQMapConstIterator<TQTab *, TQString> it;
- it = tabTips.tqfind( tab );
+ it = tabTips.find( tab );
if ( it != tabTips.end() )
return it.data();
else
@@ -293,14 +293,14 @@ protected:
tb->d->leftB->width(), tb->d->leftB->height() );
rectR.setRect( tb->d->rightB->x(), tb->d->rightB->y(),
tb->d->rightB->width(), tb->d->rightB->height() );
- if ( tb->d->scrolls && (rectL.tqcontains( p ) || rectR.tqcontains( p )) )
+ if ( tb->d->scrolls && (rectL.contains( p ) || rectR.contains( p )) )
return;
#ifndef TQT_NO_TOOLTIP
// tqfind and show the tool tip for the tab under the point p
TQMapIterator<TQTab *, TQString> it;
for ( it = tabTips.begin(); it != tabTips.end(); ++it ) {
- if ( it.key()->rect().tqcontains( p ) )
+ if ( it.key()->rect().contains( p ) )
tip( it.key()->rect(), it.data() );
}
#endif
@@ -387,7 +387,7 @@ TQTabBar::~TQTabBar()
Adds the tab, \a newTab, to the tab control.
Sets \a newTab's id to a new id and places the tab just to the
- right of the existing tabs. If the tab's label tqcontains an
+ right of the existing tabs. If the tab's label contains an
ampersand, the letter following the ampersand is used as an
accelerator for the tab, e.g. if the label is "Bro\&wse" then
Alt+W becomes an accelerator which will move the focus to this
@@ -408,7 +408,7 @@ int TQTabBar::addTab( TQTab * newTab )
If \a index is not specified, the tab is simply appended.
Otherwise it's inserted at the specified position.
- Sets \a newTab's id to a new id. If the tab's label tqcontains an
+ Sets \a newTab's id to a new id. If the tab's label contains an
ampersand, the letter following the ampersand is used as an
accelerator for the tab, e.g. if the label is "Bro\&wse" then
Alt+W becomes an accelerator which will move the focus to this
@@ -515,7 +515,7 @@ void TQTabBar::setTabEnabled( int id, bool enabled )
}
if ( t->enabled ) {
r = r.unite( t->r );
- l->append( l->take( l->tqfindRef( t ) ) );
+ l->append( l->take( l->findRef( t ) ) );
emit selected( t->id );
}
}
@@ -592,7 +592,7 @@ void TQTabBar::paint( TQPainter * p, TQTab * t, bool selected ) const
else if(t == d->pressed)
flags |= TQStyle::Style_Sunken;
//selection flags
- if(t->rect().tqcontains(mapFromGlobal(TQCursor::pos())))
+ if(t->rect().contains(mapFromGlobal(TQCursor::pos())))
flags |= TQStyle::Style_MouseOver;
tqstyle().tqdrawControl( TQStyle::CE_TabBarTab, p, this, t->rect(),
tqcolorGroup(), flags, TQStyleOption(t) );
@@ -608,8 +608,8 @@ void TQTabBar::paint( TQPainter * p, TQTab * t, bool selected ) const
}
TQFontMetrics fm = p->fontMetrics();
int fw = fm.width( t->label );
- fw -= t->label.tqcontains('&') * fm.width('&');
- fw += t->label.tqcontains("&&") * fm.width('&');
+ fw -= t->label.contains('&') * fm.width('&');
+ fw += t->label.contains("&&") * fm.width('&');
int w = iw + fw + 4;
int h = TQMAX(fm.height() + 4, ih );
int offset = 3;
@@ -662,7 +662,7 @@ void TQTabBar::paintLabel( TQPainter* p, const TQRect& br,
flags |= TQStyle::Style_Selected;
else if(t == d->pressed)
flags |= TQStyle::Style_Sunken;
- if(t->rect().tqcontains(mapFromGlobal(TQCursor::pos())))
+ if(t->rect().contains(mapFromGlobal(TQCursor::pos())))
flags |= TQStyle::Style_MouseOver;
tqstyle().tqdrawControl( TQStyle::CE_TabBarLabel, p, this, r,
t->isEnabled() ? tqcolorGroup(): tqpalette().disabled(),
@@ -721,8 +721,8 @@ void TQTabBar::paintEvent( TQPaintEvent * e )
/*!
This virtual function is called by the mouse event handlers to
determine which tab is pressed. The default implementation returns
- a pointer to the tab whose bounding rectangle tqcontains \a p, if
- exactly one tab's bounding rectangle tqcontains \a p. Otherwise it
+ a pointer to the tab whose bounding rectangle contains \a p, if
+ exactly one tab's bounding rectangle contains \a p. Otherwise it
returns 0.
\sa mousePressEvent() mouseReleaseEvent()
@@ -738,7 +738,7 @@ TQTab * TQTabBar::selectTab( const TQPoint & p ) const
TQTab * t = i.current();
++i;
- if ( t && t->r.tqcontains( p ) ) {
+ if ( t && t->r.contains( p ) ) {
if ( selected )
moreThanOne = TRUE;
else
@@ -866,7 +866,7 @@ void TQTabBar::setCurrentTab( TQTab * tab )
return;
TQRect r = l->last()->r;
- if ( l->tqfindRef( tab ) >= 0 )
+ if ( l->findRef( tab ) >= 0 )
l->append( l->take() );
d->focus = tab->id;
@@ -896,7 +896,7 @@ void TQTabBar::setCurrentTab( TQTab * tab )
\property TQTabBar::keyboardFocusTab
\brief the id of the tab that has the keyboard focus
- This property tqcontains the id of the tab that has the keyboard
+ This property contains the id of the tab that has the keyboard
focus or -1 if the tab bar does not have the keyboard focus.
*/
@@ -1095,8 +1095,8 @@ void TQTabBar::layoutTabs()
int offset = (t && d->scrolls) ? t->r.x() : 0;
while ( t ) {
int lw = fm.width( t->label );
- lw -= t->label.tqcontains('&') * fm.width('&');
- lw += t->label.tqcontains("&&") * fm.width('&');
+ lw -= t->label.contains('&') * fm.width('&');
+ lw += t->label.contains("&&") * fm.width('&');
int iw = 0;
int ih = 0;
if ( t->iconset != 0 ) {
@@ -293,14 +293,14 @@ protected:
return;
#ifndef TQT_NO_TOOLTIP
- // tqfind and show the tool tip for the tab under the point p
+ // find and show the tool tip for the tab under the point p
TQMapIterator<TQTab *, TQString> it;
for ( it = tabTips.begin(); it != tabTips.end(); ++it ) {